@@ -3,7 +3,7 @@ from .rule_parsing import curparse, preparse, postparse
 from numpy import array, linspace
 from scipy.interpolate import interp1d
 from copy import deepcopy
-from collections import defaultdict
+from collections import defaultdict, OrderedDict
 import re
 import string
 try:
@@ -62,7 +62,7 @@ class LinguisticVariable(object):
 		This method provides the leftmost and rightmost values of the universe of discourse of the linguistic variable.
 
 		Returns:
-			the two extreme values of the universe of discourse
+			the two extreme values of the universe of discourse.
 		"""
 		if self._universe_of_discourse is not None:
 			return self._universe_of_discourse
@@ -111,7 +111,7 @@ class LinguisticVariable(object):
 					color="lightgray"
 				ax.plot(x,y, linestyles[nn%4], lw=lw, label=fs._term, color=color)
 			else:
-				sns.regplot(fs._points.T[0], fs._points.T[1], marker="d", color="red", fit_reg=False, ax=ax)
+				sns.regplot(x=fs._points.T[0], y=fs._points.T[1], marker="d", color="red", fit_reg=False, ax=ax)
 				f = interp1d(fs._points.T[0], fs._points.T[1], bounds_error=False, fill_value=(fs.boundary_values[0], fs.boundary_values[1]))
 				ax.plot(x, f(x), linestyles[nn%4], label=fs._term,)
 		if TGT is not None:
@@ -155,7 +155,7 @@ class LinguisticVariable(object):
 			text = "N/A"
 		else:
 			text = self._concept
-		return "L.V.: "+text
+		return "<Linguistic variable '"+text+"', contains fuzzy sets %s, universe of discourse: %s>" % (str(self._FSlist), str(self._universe_of_discourse))
 
 
 class AutoTriangle(LinguisticVariable):
@@ -217,11 +217,11 @@ class FuzzySystem(object):
 	def __init__(self, operators=None, show_banner=True, sanitize_input=False, verbose=True):
 
 		self._rules = []
-		self._lvs = {}
-		self._variables = {}
-		self._crispvalues = {}
-		self._outputfunctions = {}
-		self._outputfuzzysets = {}
+		self._lvs = OrderedDict()
+		self._variables = OrderedDict()
+		self._crispvalues = OrderedDict()
+		self._outputfunctions = OrderedDict()
+		self._outputfuzzysets = OrderedDict()
 
 		self._constants = []
 		
@@ -248,6 +248,43 @@ class FuzzySystem(object):
 		print()
 
 
+	def get_fuzzy_sets(self, variable_name):
+		"""
+			Returns the list of FuzzySet objects associated to one linguistic variable.
+			
+			Args:
+				variable_name: name of the linguistic variable.
+
+			Returns:
+				a list containing FuzzySet objects.
+		"""
+		try:
+			return self._lvs[variable_name]._FSlist
+		except ValueError:
+			raise Exception("ERROR: linguistic variable %s does not exist" % variable_name)
+
+	def get_fuzzy_set(self, variable_name, fs_name):
+		"""
+			Returns a FuzzySet object associated to a linguistic variable.
+			
+			Args:
+				variable_name: name of the linguistic variable.
+				fs_name: linguistic term associated to the fuzzy set.
+
+			Returns:
+				a FuzzySet object.
+		"""
+		try:
+			LV =  self._lvs[variable_name]
+		except ValueError:
+			raise Exception("ERROR: linguistic variable %s does not exist" % (variable_name))
+
+		for fs in LV._FSlist:
+			if fs._term==fs_name:		return fs
+
+		raise Exception("ERROR: fuzzy set %s of linguistic variable %s does not exist" % (fs_name, variable_name))
+
+
 	def set_variable(self, name, value, verbose=False):
 		"""
 		Sets the numerical value of a linguistic variable.
@@ -306,7 +343,7 @@ class FuzzySystem(object):
 
 		Args:
 			rules: list of fuzzy rules to be added. Rules must be specified as strings, respecting Simpful's syntax.
-			sanitize: True/False, automatically removes non alphanumeric symbols from rules
+			sanitize: True/False, automatically removes non alphanumeric symbols from rules.
 			verbose: True/False, toggles verbose mode.
 		"""
 		for rule in rules:
@@ -380,11 +417,11 @@ class FuzzySystem(object):
 
 	def get_firing_strengths(self):
 		"""
-			This method returns a list of the firing strengths of the the rules, 
+			Returns a list of the firing strengths of the the rules, 
 			given the current state of input variables.
 
 			Returns:
-				a list containing rules' firing strengths
+				a list containing rules' firing strengths.
 		"""
 		results = [float(antecedent[0].evaluate(self)) for antecedent in self._rules]
 		return results
@@ -681,7 +718,7 @@ class FuzzySystem(object):
 			r = n%max_figures_per_row
 			c = n//max_figures_per_row
 			v.draw(ax[c][r])
-			ax[c][r].set_ylim(0,1)
+			ax[c][r].set_ylim(0,1.05)
 			n+=1
 
 		for m in range(n, columns*rows):
